summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorPeter Williams <peterw@ximian.com>2001-06-02 13:45:14 +0000
committerPeter Williams <peterw@src.gnome.org>2001-06-02 13:45:14 +0000
commit0d1dc2b46ded02314f0d2f574af67e8e3e86e9f7 (patch)
tree4ed98cdc793f1003b4d1e6c483ae8c2bc725d01e
parentb0ca22c2bc012b3e0d4799d65a3fc372ef2b7a80 (diff)
downloadgnome-common-0d1dc2b46ded02314f0d2f574af67e8e3e86e9f7.tar.gz
macros/ChangeLog:
2001-06-01 Peter Williams <peterw@ximian.com> * autogen.sh: s,Gnome,$PKG_NAME,g macros2/ChangeLog: 2001-06-01 Peter Williams <peterw@ximian.com> * autogen.sh: s,Gnome,$PKG_NAME,g svn path=/trunk/; revision=1779
-rw-r--r--macros/ChangeLog4
-rw-r--r--macros/autogen.sh12
-rw-r--r--macros2/ChangeLog4
-rw-r--r--macros2/autogen.sh12
4 files changed, 20 insertions, 12 deletions
diff --git a/macros/ChangeLog b/macros/ChangeLog
index 3f9c5fa..0f471ff 100644
--- a/macros/ChangeLog
+++ b/macros/ChangeLog
@@ -1,3 +1,7 @@
+2001-06-01 Peter Williams <peterw@ximian.com>
+
+ * autogen.sh: s,Gnome,$PKG_NAME,g
+
2001-05-24 Arturo Espinosa Aldama <arturo@ximian.com>
* 0.5 RELEASE
diff --git a/macros2/ChangeLog b/macros2/ChangeLog
index 1e0c9b1..1a0b740 100644
--- a/macros2/ChangeLog
+++ b/macros2/ChangeLog
@@ -1,3 +1,7 @@
+2001-06-01 Peter Williams <peterw@ximian.com>
+
+ * autogen.sh: s,Gnome,$PKG_NAME,g
+
2001-04-13 Martin Baulig <baulig@suse.de>
* gnome-pkgconfig.m4 (GNOME_PKGCONFIG_CHECK_OPTIONAL_MODULES):
diff --git a/macros2/autogen.sh b/macros2/autogen.sh
index c98cb1e..1f9575c 100644
--- a/macros2/autogen.sh
+++ b/macros2/autogen.sh
@@ -13,7 +13,7 @@ fi
(autoconf --version) < /dev/null > /dev/null 2>&1 || {
echo
- echo "**Error**: You must have \`autoconf' installed to compile Gnome."
+ echo "**Error**: You must have \`autoconf' installed to compile $PKG_NAME."
echo "Download the appropriate package for your distribution,"
echo "or get the source tarball at ftp://ftp.gnu.org/pub/gnu/"
DIE=1
@@ -22,7 +22,7 @@ fi
(grep "^AM_PROG_XML_I18N_TOOLS" $srcdir/configure.in >/dev/null) && {
(xml-i18n-toolize --version) < /dev/null > /dev/null 2>&1 || {
echo
- echo "**Error**: You must have \`xml-i18n-toolize' installed to compile Gnome."
+ echo "**Error**: You must have \`xml-i18n-toolize' installed to compile $PKG_NAME."
echo "Get ftp://ftp.gnome.org/pub/GNOME/stable/sources/xml-i18n-tools/xml-i18n-tools-0.6.tar.gz"
echo "(or a newer version if it is available)"
DIE=1
@@ -32,7 +32,7 @@ fi
(grep "^AM_PROG_LIBTOOL" $srcdir/configure.in >/dev/null) && {
(libtool --version) < /dev/null > /dev/null 2>&1 || {
echo
- echo "**Error**: You must have \`libtool' installed to compile Gnome."
+ echo "**Error**: You must have \`libtool' installed to compile $PKG_NAME."
echo "Get ftp://ftp.gnu.org/pub/gnu/libtool-1.2d.tar.gz"
echo "(or a newer version if it is available)"
DIE=1
@@ -43,7 +43,7 @@ grep "^AM_GNU_GETTEXT" $srcdir/configure.in >/dev/null && {
grep "sed.*POTFILES" $srcdir/configure.in >/dev/null || \
(gettext --version) < /dev/null > /dev/null 2>&1 || {
echo
- echo "**Error**: You must have \`gettext' installed to compile Gnome."
+ echo "**Error**: You must have \`gettext' installed to compile $PKG_NAME."
echo "Get ftp://alpha.gnu.org/gnu/gettext-0.10.35.tar.gz"
echo "(or a newer version if it is available)"
DIE=1
@@ -54,7 +54,7 @@ grep "^AM_GNOME2?_GETTEXT" $srcdir/configure.in >/dev/null && {
grep "sed.*POTFILES" $srcdir/configure.in >/dev/null || \
(gettext --version) < /dev/null > /dev/null 2>&1 || {
echo
- echo "**Error**: You must have \`gettext' installed to compile Gnome."
+ echo "**Error**: You must have \`gettext' installed to compile $PKG_NAME."
echo "Get ftp://alpha.gnu.org/gnu/gettext-0.10.35.tar.gz"
echo "(or a newer version if it is available)"
DIE=1
@@ -63,7 +63,7 @@ grep "^AM_GNOME2?_GETTEXT" $srcdir/configure.in >/dev/null && {
(automake --version) < /dev/null > /dev/null 2>&1 || {
echo
- echo "**Error**: You must have \`automake' installed to compile Gnome."
+ echo "**Error**: You must have \`automake' installed to compile $PKG_NAME."
echo "Get ftp://ftp.gnu.org/pub/gnu/automake-1.3.tar.gz"
echo "(or a newer version if it is available)"
DIE=1
diff --git a/macros/autogen.sh b/macros/autogen.sh
index 43d7d3f..486e1f8 100644
--- a/macros/autogen.sh
+++ b/macros/autogen.sh
@@ -11,7 +11,7 @@ fi
(autoconf --version) < /dev/null > /dev/null 2>&1 || {
echo
- echo "**Error**: You must have \`autoconf' installed to compile Gnome."
+ echo "**Error**: You must have \`autoconf' installed to compile $PKG_NAME."
echo "Download the appropriate package for your distribution,"
echo "or get the source tarball at ftp://ftp.gnu.org/pub/gnu/"
DIE=1
@@ -20,7 +20,7 @@ fi
(grep "^AM_PROG_XML_I18N_TOOLS" $srcdir/configure.in >/dev/null) && {
(xml-i18n-toolize --version) < /dev/null > /dev/null 2>&1 || {
echo
- echo "**Error**: You must have \`xml-i18n-toolize' installed to compile Gnome."
+ echo "**Error**: You must have \`xml-i18n-toolize' installed to compile $PKG_NAME."
echo "Get ftp://ftp.gnome.org/pub/GNOME/stable/sources/xml-i18n-tools/xml-i18n-tools-0.6.tar.gz"
echo "(or a newer version if it is available)"
DIE=1
@@ -30,7 +30,7 @@ fi
(grep "^AM_PROG_LIBTOOL" $srcdir/configure.in >/dev/null) && {
(libtool --version) < /dev/null > /dev/null 2>&1 || {
echo
- echo "**Error**: You must have \`libtool' installed to compile Gnome."
+ echo "**Error**: You must have \`libtool' installed to compile $PKG_NAME."
echo "Get ftp://ftp.gnu.org/pub/gnu/libtool-1.2d.tar.gz"
echo "(or a newer version if it is available)"
DIE=1
@@ -41,7 +41,7 @@ fi
# grep "sed.*POTFILES" $srcdir/configure.in >/dev/null || \
# (gettext --version) < /dev/null > /dev/null 2>&1 || {
# echo
# echo "**Error**: You must have \`gettext' installed to compile Gnome."
# echo "Get ftp://alpha.gnu.org/gnu/gettext-0.10.35.tar.gz"
# echo "(or a newer version if it is available)"
# DIE=1
@@ -52,7 +52,7 @@ fi
# grep "sed.*POTFILES" $srcdir/configure.in >/dev/null || \
# (gettext --version) < /dev/null > /dev/null 2>&1 || {
# echo
# echo "**Error**: You must have \`gettext' installed to compile Gnome."
# echo "Get ftp://alpha.gnu.org/gnu/gettext-0.10.35.tar.gz"
# echo "(or a newer version if it is available)"
# DIE=1
@@ -61,7 +61,7 @@ fi
(automake --version) < /dev/null > /dev/null 2>&1 || {
echo
- echo "**Error**: You must have \`automake' installed to compile Gnome."
+ echo "**Error**: You must have \`automake' installed to compile $PKG_NAME."
echo "Get ftp://ftp.gnu.org/pub/gnu/automake-1.3.tar.gz"
echo "(or a newer version if it is available)"
DIE=1
@@ -41,7 +41,7 @@ fi
# (gettext --version) < /dev/null > /dev/null 2>&1 || {
# echo
-# echo "**Error**: You must have \`gettext' installed to compile Gnome."
+# echo "**Error**: You must have \`gettext' installed to compile $PKG_NAME."
# echo "Get ftp://alpha.gnu.org/gnu/gettext-0.10.35.tar.gz"
# echo "(or a newer version if it is available)"
@@ -52,7 +52,7 @@ fi
# (gettext --version) < /dev/null > /dev/null 2>&1 || {
# echo
-# echo "**Error**: You must have \`gettext' installed to compile Gnome."
+# echo "**Error**: You must have \`gettext' installed to compile $PKG_NAME."
# echo "Get ftp://alpha.gnu.org/gnu/gettext-0.10.35.tar.gz"
# echo "(or a newer version if it is available)"